searchData={"items":[{"type":"module","title":"AshMoney","doc":"`AshMoney` provides a type for working with money in your Ash resources.\n\nIt also provides an `AshPostgres.Extension` that can be used to add support for\nmoney types and operators to your Postgres database.","ref":"AshMoney.html"},{"type":"module","title":"AshMoney.Types.Money","doc":"A money type for Ash that uses the `ex_money` library.\n\nWhen constructing a composite type, use a tuple in the following structure:\n\n`composite_type(%{currency: \"USD\", amount: Decimal.new(\"0\")}}, AshMoney.Types.Money)`\n\nIf you've added a custom type, like `:money`:\n\n```elixir\ncomposite_type(%{currency: \"USD\", amount: Decimal.new(\"0\")}}, :money)\n```","ref":"AshMoney.Types.Money.html"},{"type":"module","title":"AshMoney.AshPostgresExtension","doc":"Installs the `money_with_currency` type and operators/functions for Postgres.","ref":"AshMoney.AshPostgresExtension.html"},{"type":"function","title":"AshMoney.AshPostgresExtension.extension/0","doc":"","ref":"AshMoney.AshPostgresExtension.html#extension/0"},{"type":"function","title":"AshMoney.AshPostgresExtension.install/1","doc":"","ref":"AshMoney.AshPostgresExtension.html#install/1"},{"type":"function","title":"AshMoney.AshPostgresExtension.uninstall/1","doc":"","ref":"AshMoney.AshPostgresExtension.html#uninstall/1"},{"type":"extras","title":"Get Started With Ash Money","doc":"# Getting Started With AshMoney","ref":"get-started-with-ash-money.html"},{"type":"extras","title":"Bring in the ash_graphql dependency - Get Started With Ash Money","doc":"```elixir\ndef deps()\n  [\n    ...\n    {:ash_money, \"~> 0.1.3\"}\n  ]\nend\n```","ref":"get-started-with-ash-money.html#bring-in-the-ash_graphql-dependency"},{"type":"extras","title":"Setup - Get Started With Ash Money","doc":"The primary thing that AshMoney provides is `AshMoney.Types.Money`. This is backed by `ex_money`. You can use it out of the box like so:\n\n```elixir\nattribute :balance, AshMoney.Types.Money\n```\n\nOr you can add it to your compile time list of types for easier reference:\n\n```elixir\nconfig :ash, :custom_types, money: AshMoney.Types.Money\n```\n\nThen compile ash again, `mix deps.compile ash --force`, and refer to it like so:\n\n```elixir\nattribute :balance, :money\n```","ref":"get-started-with-ash-money.html#setup"},{"type":"extras","title":"AshPostgres Support - Get Started With Ash Money","doc":"Add the `:ex_money_sql` dependency to your `mix.exs` file.\n\nThanks to `ex_money_sql`, there are excellent tools for lowering support for money into your postgres database. This allows for things like aggregates that sum amounts, and referencing money in expressions:\n\n```elixir\nsum :sum_of_usd_balances, :accounts, :balance do\n  filter expr(\n    fragment(\"(?).currency_code\", balance) == \"USD\"\n  )\nend\n```\n\nTo install it, add `AshMoney.AshPostgresExtension` to your list of `installed_extensions` in your repo, and generate migrations.\n\n```elixir\ndefmodule YourRepo do\n  def installed_extensions do\n    [..., AshMoney.AshPostgresExtension]\n  end\nend\n```","ref":"get-started-with-ash-money.html#ashpostgres-support"},{"type":"extras","title":"AshGraphql Support - Get Started With Ash Money","doc":"Add the following to your schema file:\n\n```elixir\n  object :money do\n    field(:amount, non_null(:decimal))\n    field(:currency, non_null(:string))\n  end\n```","ref":"get-started-with-ash-money.html#ashgraphql-support"},{"type":"extras","title":"Limitations - Get Started With Ash Money","doc":"Support for using built in operators with data layers that don't support it. For example, `expr(money + money)` will work in `AshPostgres`, but not when using `Ash.DataLayer.Ets`. \nWe need to make built in functions extensible by type to make this work.","ref":"get-started-with-ash-money.html#limitations"}],"content_type":"text/markdown"}